@@ -1,8 +1,8 @@
 {-# LANGUAGE FlexibleInstances #-}
 module Test.Hspec.Pending where
 
-import qualified Test.Hspec.Internal as Internal
-import           Test.Hspec.Internal (Example(..))
+import qualified Test.Hspec.Core.Type as Core
+import           Test.Hspec.Core.Type (Example(..))
 
 -- NOTE: This is defined in a separate packages, because it clashes with
 -- Result.Pending.
@@ -11,25 +11,24 @@ import           Test.Hspec.Internal (Example(..))
 newtype Pending = Pending (Maybe String)
 
 instance Example Pending where
-  evaluateExample (Pending reason) = evaluateExample (Internal.Pending reason)
+  evaluateExample c (Pending reason) = evaluateExample c (Core.Pending reason)
 
 instance Example (String -> Pending) where
-  evaluateExample _ = evaluateExample (Pending Nothing)
+  evaluateExample c _ = evaluateExample c (Pending Nothing)
 
 -- | A pending example.
 --
--- If you want to report on a behavior but don't have an example yet, use this.
+-- If you want to textually specify a behavior but do not have an example yet,
+-- use this:
 --
--- > describe "fancyFormatter" [
+-- > describe "fancyFormatter" $ do
 -- >   it "can format text in a way that everyone likes" $
 -- >     pending
--- > ]
 --
--- You can give an optional reason for why it's pending.
+-- You can give an optional reason for why it's pending:
 --
--- > describe "fancyFormatter" [
+-- > describe "fancyFormatter" $ do
 -- >   it "can format text in a way that everyone likes" $
 -- >     pending "waiting for clarification from the designers"
--- > ]
 pending :: String -> Pending
 pending = Pending . Just
